==> axelrod-fortran-0.3.0.tar.gz: axelrod-fortran-0.3.0/src/axelrod_fortran/strategies.py <==
import axelrod as axl

characteristics = {
    'grasr': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': None,
        'original_rank': None},
    'k31r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Gail Grisell',
        'original_rank': 23},
    'k32r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Charles Kluepfel',
        'original_rank': 10},
    'k33r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Harold Rabbie',
        'original_rank': 59},
    'k34r': {
        'axelrod-python_class': axl.Grudger,
        'stochastic': False,
        'author': 'James W Friedman',
        'original_rank': 52},
    'k35r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Abraham Getzler',
        'original_rank': 11},
    'k36r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Roger Hotz',
        'original_rank': 63},
    'k37r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Lefevre',
        'original_rank': 37},
    'k38r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Nelson Weiderman',
        'original_rank': 34},
    'k39r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Tom Almy',
        'original_rank': 25},
    'k40r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Robert Adams',
        'original_rank': 35},
    'k41r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Herb Weiner',
        'original_rank': 7},
    'k42r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Otto Borufsen',
        'original_rank': 3},
    'k43r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'R D Anderson',
        'original_rank': 39},
    'k44r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'William Adams',
        'original_rank': 5},
    'k45r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Michael F McGurrin',
        'original_rank': 50},
    'k46r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Graham J Eatherley',
        'original_rank': 14},
    'k47r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Richard Hufford',
        'original_rank': 16},
    'k48r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Hufford',
        'original_rank': 53},
    'k49r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Rob Cave',
        'original_rank': 4},
    'k50r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Rik Smoody',
        'original_rank': 54},
    'k51r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'John William Colbert',
        'original_rank': 18},
    'k52r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'David A Smith',
        'original_rank': 48},
    'k53r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Henry Nussbacher',
        'original_rank': 45},
    'k54r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'William H Robertson',
        'original_rank': 58},
    'k55r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Steve Newman',
        'original_rank': 42},
    'k56r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Stanley F Quayle',
        'original_rank': 38},
    'k57r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Rudy Nydegger',
        'original_rank': 31},
    'k58r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Glen Rowsam',
        'original_rank': 21},
    'k59r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Leslie Downing',
        'original_rank': 40},
    'k60r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Jim Graaskamp and Ken Katzen',
        'original_rank': 6},
    'k61r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Danny C Champion',
        'original_rank': 2},
    'k62r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Howard R Hollander',
        'original_rank': 51},
    'k63r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Duisman',
        'original_rank': 57},
    'k64r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Brian Yamachi',
        'original_rank': 17},
    'k65r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Mark F Batell',
        'original_rank': 47},
    'k66r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Ray Mikkelson',
        'original_rank': 20},
    'k67r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Craig Feathers',
        'original_rank': 27},
    'k68r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Fransois Leyvraz',
        'original_rank': 12},
    'k69r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Johann Joss',
        'original_rank': 29},
    'k70r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Robert Pebly',
        'original_rank': 32},
    'k71r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'James E Hall',
        'original_rank': 60},
    'k72r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Edward C White Jr',
        'original_rank': 13},
    'k73r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Zimmerman',
        'original_rank': 41},
    'k74r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Edward Friedland',
        'original_rank': 61},
    'k74rxx': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Edward Friedland',
        'original_rank': None},
    'k75r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Paul D Harrington',
        'original_rank': 8},
    'k76r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'David Gladstein',
        'original_rank': 46},
    'k77r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Scott Feld',
        'original_rank': 55},
    'k78r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Fred Mauk',
        'original_rank': 19},
    'k79r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Dennis Ambuehl and Kevin Hickey',
        'original_rank': 26},
    'k80r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Robyn M Dawes and Mark Batell',
        'original_rank': 36},
    'k81r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Martyn Jones',
        'original_rank': 43},
    'k82r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Robert A Leyland',
        'original_rank': 49},
    'k83r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Paul E Black',
        'original_rank': 15},
    'k84r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'T Nicolaus Tideman and Paula Chieruzz',
        'original_rank': 9},
    'k85r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Robert B Falk and James M Langsted',
        'original_rank': 33},
    'k86r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Bernard Grofman',
        'original_rank': 28},
    'k87r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'E E H Schurmann',
        'original_rank': 44},
    'k88r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Scott Appold',
        'original_rank': 22},
    'k89r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Gene Snodgrass',
        'original_rank': 56},
    'k90r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'John Maynard Smith',
        'original_rank': 24},
    'k91r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Jonathan Pinkley',
        'original_rank': 30},
    'k92r': {
        'axelrod-python_class': axl.TitForTat,
        'stochastic': False,
        'author': 'Anatol Rapoport',
        'original_rank': 1},
    'k93r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': None,
        'original_rank': None},
    'kpavlovc': {
        'axelrod-python_class': axl.WinStayLoseShift,
        'stochastic': False,
        'author': None,
        'original_rank': None},
    'krandomc': {
        'axelrod-python_class': axl.Random,
        'stochastic': True,
        'author': None,
        'original_rank': 62},
    'ktf2tc': {
        'axelrod-python_class': axl.TitFor2Tats,
        'stochastic': False,
        'author': None,
        'original_rank': None},
    'ktitfortatc': {
        'axelrod-python_class': axl.TitForTat,
        'stochastic': False,
        'author': None,
        'original_rank': None},
}

all_strategies = characteristics.keys()

# Players from Axelrod's second tournament.
second_tournament_strategies = [
    name for name in characteristics.keys()
    if characteristics[name]["original_rank"] is not None]

representative_strategies = ['k60r', 'k91r', 'k40r', 'k76r', 'k67r']

==> axelrod-fortran-0.4.8.tar.gz: axelrod-fortran-0.4.8/src/axelrod_fortran/strategies.py <==
import axelrod as axl

characteristics = {
    'grasr': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': None,
        'original_rank': None},
    'k31r': {
        'axelrod-python_class': axl.GoByMajority,
        'stochastic': False,
        'author': 'Gail Grisell',
        'original_rank': 23},
    'k32r': {
        'axelrod-python_class': axl.SecondByKluepfel,
        'stochastic': True,
        'author': 'Charles Kluepfel',
        'original_rank': 10},
    'k33r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Harold Rabbie',
        'original_rank': 59},
    'k34r': {
        'axelrod-python_class': axl.Grudger,
        'stochastic': False,
        'author': 'James W Friedman',
        'original_rank': 52},
    'k35r': {
        'axelrod-python_class': axl.SecondByGetzler,
        'stochastic': True,
        'author': 'Abraham Getzler',
        'original_rank': 11},
    'k36r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Roger Hotz',
        'original_rank': 63},
    'k37r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Lefevre',
        'original_rank': 37},
    'k38r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Nelson Weiderman',
        'original_rank': 34},
    'k39r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Tom Almy',
        'original_rank': 25},
    'k40r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Robert Adams',
        'original_rank': 35},
    'k41r': {
        'axelrod-python_class': axl.SecondByWeiner,
        'stochastic': False,
        'author': 'Herb Weiner',
        'original_rank': 7},
    'k42r': {
        'axelrod-python_class': axl.SecondByBorufsen,
        'stochastic': False,
        'author': 'Otto Borufsen',
        'original_rank': 3},
    'k43r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'R D Anderson',
        'original_rank': 39},
    'k44r': {
        'axelrod-python_class': axl.SecondByWmAdams,
        'stochastic': True,
        'author': 'William Adams',
        'original_rank': 5},
    'k45r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Michael F McGurrin',
        'original_rank': 50},
    'k46r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Graham J Eatherley',
        'original_rank': 14},
    'k47r': {
        'axelrod-python_class': axl.SecondByRichardHufford,
        'stochastic': False,
        'author': 'Richard Hufford',
        'original_rank': 16},
    'k48r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Hufford',
        'original_rank': 53},
    'k49r': {
        'axelrod-python_class': axl.SecondByCave,
        'stochastic': True,
        'author': 'Rob Cave',
        'original_rank': 4},
    'k50r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Rik Smoody',
        'original_rank': 54},
    'k51r': {
        'axelrod-python_class': axl.SecondByColbert,
        'stochastic': False,
        'author': 'John William Colbert',
        'original_rank': 18},
    'k52r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'David A Smith',
        'original_rank': 48},
    'k53r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Henry Nussbacher',
        'original_rank': 45},
    'k54r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'William H Robertson',
        'original_rank': 58},
    'k55r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Steve Newman',
        'original_rank': 42},
    'k56r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Stanley F Quayle',
        'original_rank': 38},
    'k57r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Rudy Nydegger',
        'original_rank': 31},
    'k58r': {
        'axelrod-python_class': axl.SecondByRowsam,
        'stochastic': False,
        'author': 'Glen Rowsam',
        'original_rank': 21},
    'k59r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Leslie Downing',
        'original_rank': 40},
    'k60r': {
        'axelrod-python_class': axl.SecondByGraaskampKatzen,
        'stochastic': False,
        'author': 'Jim Graaskamp and Ken Katzen',
        'original_rank': 6},
    'k61r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Danny C Champion',
        'original_rank': 2},
    'k62r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Howard R Hollander',
        'original_rank': 51},
    'k63r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Duisman',
        'original_rank': 57},
    'k64r': {
        'axelrod-python_class': axl.SecondByYamachi,
        'stochastic': False,
        'author': 'Brian Yamachi',
        'original_rank': 17},
    'k65r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Mark F Batell',
        'original_rank': 47},
    'k66r': {
        'axelrod-python_class': axl.SecondByMikkelson,
        'stochastic': False,
        'author': 'Ray Mikkelson',
        'original_rank': 20},
    'k67r': {
        'axelrod-python_class': axl.SecondByTranquilizer,
        'stochastic': True,
        'author': 'Craig Feathers',
        'original_rank': 27},
    'k68r': {
        'axelrod-python_class': axl.SecondByLeyvraz,
        'stochastic': True,
        'author': 'Fransois Leyvraz',
        'original_rank': 12},
    'k69r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Johann Joss',
        'original_rank': 29},
    'k70r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Robert Pebly',
        'original_rank': 32},
    'k71r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'James E Hall',
        'original_rank': 60},
    'k72r': {
        'axelrod-python_class': axl.SecondByWhite,
        'stochastic': True,
        'author': 'Edward C White Jr',
        'original_rank': 13},
    'k73r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'George Zimmerman',
        'original_rank': 41},
    'k74r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Edward Friedland',
        'original_rank': 61},
    'k74rxx': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Edward Friedland',
        'original_rank': None},
    'k75r': {
        'axelrod-python_class': axl.SecondByHarrington,
        'stochastic': True,
        'author': 'Paul D Harrington',
        'original_rank': 8},
    'k76r': {
        'axelrod-python_class': axl.SecondByGladstein,
        'stochastic': False,
        'author': 'David Gladstein',
        'original_rank': 46},
    'k77r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Scott Feld',
        'original_rank': 55},
    'k78r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Fred Mauk',
        'original_rank': 19},
    'k79r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Dennis Ambuehl and Kevin Hickey',
        'original_rank': 26},
    'k80r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Robyn M Dawes and Mark Batell',
        'original_rank': 36},
    'k81r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Martyn Jones',
        'original_rank': 43},
    'k82r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Robert A Leyland',
        'original_rank': 49},
    'k83r': {
        'axelrod-python_class': axl.SecondByBlack,
        'stochastic': True,
        'author': 'Paul E Black',
        'original_rank': 15},
    'k84r': {
        'axelrod-python_class': axl.SecondByTidemanAndChieruzzi,
        'stochastic': False,
        'author': 'T Nicolaus Tideman and Paula Chieruzz',
        'original_rank': 9},
    'k85r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Robert B Falk and James M Langsted',
        'original_rank': 33},
    'k86r': {
        'axelrod-python_class': axl.SecondByGrofman,
        'stochastic': False,
        'author': 'Bernard Grofman',
        'original_rank': 28},
    'k87r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'E E H Schurmann',
        'original_rank': 44},
    'k88r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': 'Scott Appold',
        'original_rank': 22},
    'k89r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Gene Snodgrass',
        'original_rank': 56},
    'k90r': {
        'axelrod-python_class': axl.TitFor2Tats,
        'stochastic': False,
        'author': 'John Maynard Smith',
        'original_rank': 24},
    'k91r': {
        'axelrod-python_class': None,
        'stochastic': False,
        'author': 'Jonathan Pinkley',
        'original_rank': 30},
    'k92r': {
        'axelrod-python_class': axl.TitForTat,
        'stochastic': False,
        'author': 'Anatol Rapoport',
        'original_rank': 1},
    'k93r': {
        'axelrod-python_class': None,
        'stochastic': True,
        'author': None,
        'original_rank': None},
    'kpavlovc': {
        'axelrod-python_class': axl.WinStayLoseShift,
        'stochastic': False,
        'author': None,
        'original_rank': None},
    'krandomc': {
        'axelrod-python_class': axl.Random,
        'stochastic': True,
        'author': None,
        'original_rank': 62},
    'ktf2tc': {
        'axelrod-python_class': axl.TitFor2Tats,
        'stochastic': False,
        'author': None,
        'original_rank': None},
    'ktitfortatc': {
        'axelrod-python_class': axl.TitForTat,
        'stochastic': False,
        'author': None,
        'original_rank': None},
}

all_strategies = list(characteristics.keys())

# Players from Axelrod's second tournament.
second_tournament_strategies = [
    name for name in characteristics.keys()
    if characteristics[name]["original_rank"] is not None]

representative_strategies = ['k60r', 'k91r', 'k40r', 'k76r', 'k67r']
